@@ -39,6 +39,7 @@ class Settings(TypedDict, total=False):
     use_shortcuts: bool
     style: Optional[List[Tuple[str, str]]]
     customize: CzSettings
+    major_version_zero: bool
 
 
 name: str = "cz_conventional_commits"
@@ -63,6 +64,7 @@ DEFAULT_SETTINGS: Settings = {
     "changelog_start_rev": None,
     "update_changelog_on_bump": False,
     "use_shortcuts": False,
+    "major_version_zero": False,
 }
 
 MAJOR = "MAJOR"
@@ -80,6 +82,16 @@ bump_map = OrderedDict(
         (r"^perf", PATCH),
     )
 )
+bump_map_major_version_zero = OrderedDict(
+    (
+        (r"^.+!$", MINOR),
+        (r"^BREAKING[\-\ ]CHANGE", MINOR),
+        (r"^feat", MINOR),
+        (r"^fix", PATCH),
+        (r"^refactor", PATCH),
+        (r"^perf", PATCH),
+    )
+)
 change_type_order = ["BREAKING CHANGE", "Feat", "Fix", "Refactor", "Perf"]
 bump_message = "bump: version $current_version → $new_version"
 
